#ifndef __NET_H__
#define __NET_H__

#include "hardinfo.h"

typedef struct _NetDevice	NetDevice;

struct _NetDevice {
	gchar *iface;
	
	gulong recv_bytes;
	gulong recv_errors;
	gulong recv_packets;
	
	gulong trans_bytes;
	gulong trans_errors;
	gulong trans_packets;

	NetDevice *next;
};


NetDevice *hi_scan_net(void);
GtkWidget *net_get_widget(MainWindow *mainwindow);
void hi_show_net_info(MainWindow *mainwindow, NetDevice *device);

gboolean net_update(gpointer data);

#endif
